==> okta-sdk-api-20.0.1-sources.jar: com/okta/sdk/resource/model/ApplicationGroupAssignmentLinks.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.HrefObjectAppLink;
import com.okta.sdk.resource.model.HrefObjectGroupLink;
import com.okta.sdk.resource.model.HrefObjectSelfLink;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * ApplicationGroupAssignmentLinks
 */
@JsonPropertyOrder({ ApplicationGroupAssignmentLinks.JSON_PROPERTY_SELF,
        ApplicationGroupAssignmentLinks.JSON_PROPERTY_APP, ApplicationGroupAssignmentLinks.JSON_PROPERTY_GROUP })
@JsonTypeName("ApplicationGroupAssignment__links")
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-01-23T09:50:29.349096-06:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class ApplicationGroupAssignmentLinks implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_SELF = "self";
    private HrefObjectSelfLink self;

    public static final String JSON_PROPERTY_APP = "app";
    private HrefObjectAppLink app;

    public static final String JSON_PROPERTY_GROUP = "group";
    private HrefObjectGroupLink group;

    public ApplicationGroupAssignmentLinks() {
    }

    public ApplicationGroupAssignmentLinks self(HrefObjectSelfLink self) {

        this.self = self;
        return this;
    }

    /**
     * Get self
     *
     * @return self
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_SELF)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public HrefObjectSelfLink getSelf() {
        return self;
    }

    @JsonProperty(JSON_PROPERTY_SELF)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setSelf(HrefObjectSelfLink self) {
        this.self = self;
    }

    public ApplicationGroupAssignmentLinks app(HrefObjectAppLink app) {

        this.app = app;
        return this;
    }

    /**
     * Get app
     *
     * @return app
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_APP)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public HrefObjectAppLink getApp() {
        return app;
    }

    @JsonProperty(JSON_PROPERTY_APP)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setApp(HrefObjectAppLink app) {
        this.app = app;
    }

    public ApplicationGroupAssignmentLinks group(HrefObjectGroupLink group) {

        this.group = group;
        return this;
    }

    /**
     * Get group
     *
     * @return group
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_GROUP)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public HrefObjectGroupLink getGroup() {
        return group;
    }

    @JsonProperty(JSON_PROPERTY_GROUP)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setGroup(HrefObjectGroupLink group) {
        this.group = group;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        ApplicationGroupAssignmentLinks applicationGroupAssignmentLinks = (ApplicationGroupAssignmentLinks) o;
        return Objects.equals(this.self, applicationGroupAssignmentLinks.self)
                && Objects.equals(this.app, applicationGroupAssignmentLinks.app)
                && Objects.equals(this.group, applicationGroupAssignmentLinks.group);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(self, app, group);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class ApplicationGroupAssignmentLinks {\n");
        sb.append("    self: ").append(toIndentedString(self)).append("\n");
        sb.append("    app: ").append(toIndentedString(app)).append("\n");
        sb.append("    group: ").append(toIndentedString(group)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}

==> okta-sdk-api-23.0.0-sources.jar: com/okta/sdk/resource/model/ApplicationGroupAssignmentLinks.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.HrefObjectAppLink;
import com.okta.sdk.resource.model.HrefObjectGroupLink;
import com.okta.sdk.resource.model.HrefObjectSelfLink;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * ApplicationGroupAssignmentLinks
 */
@JsonPropertyOrder({ ApplicationGroupAssignmentLinks.JSON_PROPERTY_SELF,
        ApplicationGroupAssignmentLinks.JSON_PROPERTY_APP, ApplicationGroupAssignmentLinks.JSON_PROPERTY_GROUP })
@JsonTypeName("ApplicationGroupAssignment__links")
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-05-05T16:46:15.395194+05:30[Asia/Kolkata]", comments = "Generator version: 7.11.0")
public class ApplicationGroupAssignmentLinks implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_SELF = "self";
    private HrefObjectSelfLink self;

    public static final String JSON_PROPERTY_APP = "app";
    private HrefObjectAppLink app;

    public static final String JSON_PROPERTY_GROUP = "group";
    private HrefObjectGroupLink group;

    public ApplicationGroupAssignmentLinks() {
    }

    public ApplicationGroupAssignmentLinks self(HrefObjectSelfLink self) {

        this.self = self;
        return this;
    }

    /**
     * Get self
     *
     * @return self
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_SELF)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public HrefObjectSelfLink getSelf() {
        return self;
    }

    @JsonProperty(JSON_PROPERTY_SELF)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setSelf(HrefObjectSelfLink self) {
        this.self = self;
    }

    public ApplicationGroupAssignmentLinks app(HrefObjectAppLink app) {

        this.app = app;
        return this;
    }

    /**
     * Get app
     *
     * @return app
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_APP)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public HrefObjectAppLink getApp() {
        return app;
    }

    @JsonProperty(JSON_PROPERTY_APP)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setApp(HrefObjectAppLink app) {
        this.app = app;
    }

    public ApplicationGroupAssignmentLinks group(HrefObjectGroupLink group) {

        this.group = group;
        return this;
    }

    /**
     * Get group
     *
     * @return group
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_GROUP)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public HrefObjectGroupLink getGroup() {
        return group;
    }

    @JsonProperty(JSON_PROPERTY_GROUP)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setGroup(HrefObjectGroupLink group) {
        this.group = group;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        ApplicationGroupAssignmentLinks applicationGroupAssignmentLinks = (ApplicationGroupAssignmentLinks) o;
        return Objects.equals(this.self, applicationGroupAssignmentLinks.self)
                && Objects.equals(this.app, applicationGroupAssignmentLinks.app)
                && Objects.equals(this.group, applicationGroupAssignmentLinks.group);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(self, app, group);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class ApplicationGroupAssignmentLinks {\n");
        sb.append("    self: ").append(toIndentedString(self)).append("\n");
        sb.append("    app: ").append(toIndentedString(app)).append("\n");
        sb.append("    group: ").append(toIndentedString(group)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}
